#ifndef SG642USB_H
#define SG642USB_H

#ifdef SG642USB_Exports
#define SG642USB_API __declspec(dllexport)
#else
#define SG642USB_API __declspec(dllimport)
#endif

extern "C"
 {
//Open device named as "SG-642":
//returns true if device opens correctly.
  SG642USB_API bool WINAPI SG642_OpenDevice(void);

//Close device:
//returns true if device closes correctly.
  SG642USB_API bool WINAPI SG642_CloseDevice(void);

//Get last error name:
//returns pointer to last error name string
//(empty string if error not occured).
  SG642USB_API void WINAPI SG642_GetLastError(LPCSTR &lpcStr);

//Get device info:
//returns pointer to device name string.
//Device name string is "SG-642 V1.0", where
//"SG-642" is device name, "V1.0" is firmware version
//(may be different).
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_GetInfo(LPCSTR &lpcStr);

//Set device control mode:
//bit mode.0 - device local control (encoder and pushbuttons) lock
//mode.0 = 0 - device local control is unlocked
//mode.0 = 1 - device local control is locked
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_SetMode(int mode);

//Read current device control mode:
//bit mode.0 - device local control (encoder and pushbuttons) lock
//mode.0 = 0 - device local control is unlocked
//mode.0 = 1 - device local control is locked
//bit mode.1 - SG642_SetPar command sound signal on/off
//mode.1 = 0 - sound is on
//mode.1 = 1 - sound is off
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_GetMode(int &mode);

//Set parameter value:
//ch - channel number
//par - parameter number
//val - parameter value
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_SetPar(int ch, int par, int val);

//Read parameter value:
//ch - channel number
//par - parameter number
//val - parameter value
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_GetPar(int ch, int par, int &val);

//Read selected parameter value:
//ch - channel number
//par - parameter number
//val - parameter value
//Returns true if device responds correctly.
  SG642USB_API bool WINAPI SG642_GetSelPar(int &ch, int &par, int &val);
 }

//Channels numbers:

enum { OUT_A,     //OUT A
       OUT_B,     //OUT B
       CALIB,     //CALIBRATION
       SETUP };   //SETUP

//Params for OUT_A, OUT_B channels:

enum { PAR_M,     //mode,            range 0..1
       PAR_S,     //shape,           range 0..1
       PAR_F,     //frequency,       range 0..500000000.001 Hz
       PAR_P,     //phase,           range 36000.1
       PAR_A,     //amplitude,       range 0..1000000.1 mV
       PAR_R };   //attenuator,      range -1..3

//Params for CALIB channel:

enum { CAL_F,     //calib. frequency range 999
       CAL_A,     //calib. level A   range 999
       CAL_B,     //calib. level B   range 999
       CAL_S };   //save calib.

//Params for SETUP channel:

enum { SAVE_P,    //save preset,     range 0..9
       READ_P,    //read preset,     range 0..9
       LCD_C,     //LCD contrast,    range 0..127
       SAVE_S };  //save settings,   range -

//Params modifiers:

#define OUTS       (OUT_B + 1)
#define POUTS_MAX  (PAR_R + 1)
#define PCALIB_MAX (CAL_S + 1)
#define PSETUP_MAX (SAVE_S + 1)

//#define MODE_LOCK 0x01 //lock code
//#define MODE_MUTE 0x02 //mute code
//#define NODRAW    0x80 //no draw bit

#define DRAW 0x80 //draw bit
#define BEEP 0x40 //beep bit

//Mode codes (PAR_M):

enum { MD_SPLIT,   //independed channels
       MD_COMBO }; //combined channels

//Shape codes (PAR_S):

enum { SH_S,      //sine
       SH_M };    //meander

//Attenuator control codes (PAR_R):

#define REL_AUTO -1 //attenuator AUTO
#define REL_OFF   0 //attenuator OFF
#define REL_40DB  1 //attenuator -40dB
#define REL_20DB  2 //attenuator -20dB
#define REL_0DB   3 //attenuator 0dB

#endif


